from django.contrib import admin
from treebeard.admin import TreeAdmin


class AbstractProductCategoryAdmin(admin.ModelAdmin):
    list_display = ['name', 'description',]
    search_fields = ['name', 'description',]


class AbstractNestedProductCategoryAdmin(TreeAdmin, AbstractProductCategoryAdmin):
    pass




from django.contrib import admin
from django.utils.translation import ugettext_lazy as _


class AbstractProductAdmin(admin.ModelAdmin):
    list_display = ['item_number', 'name',]
    search_fields = ['item_number', 'name',]
    fieldsets = [
        [_("Basics"), {
            'fields': ['item_number', 'name', 'description',],
        }],
    ]




from django.contrib.auth.models import User
import factory

from eca_catalogue.text.tests.models import WashingInstruction


class WashingInstructionFactory(factory.Factory):
    FACTORY_FOR = WashingInstruction

    icon = "icon.png"
    text = "text"




from django.db import models
from django.utils.translation import ugettext_lazy as _


class AbstractProduct(models.Model):
    item_number = models.CharField(_("Item number"), max_length=255, unique=True)
    name = models.CharField(_("Name"), max_length=128)
    description = models.TextField(_("Description"), blank=True, null=True)

    class Meta:
        abstract = True
        verbose_name = _("Product")
        verbose_name_plural = _("Products")
        ordering = ['item_number']

    def __unicode__(self):
        return "%s (%s)" % (self.name, self.item_number)




#!/usr/bin/env python
"""
Inspired by https://github.com/mbrochh/tdd-with-django-reusable-app
Thanks a lot!

"""
import os
import sys

from django.conf import settings

EXTERNAL_APPS = [
    'django.contrib.admin',
    'django.contrib.admindocs',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.messages',
    'django.contrib.sessions',
    'django.contrib.staticfiles',
    'django.contrib.sitemaps',
    'django.contrib.sites',
]
INTERNAL_APPS = [
    'django_nose',
    'eca_catalogue',
    'eca_catalogue.text.tests',
    'eca_catalogue.categorization.tests',
    'eca_catalogue.material.tests',
    'eca_catalogue.measurement.tests',
    'eca_catalogue.product.tests',
    'eca_catalogue.tests',
]
INSTALLED_APPS = EXTERNAL_APPS + INTERNAL_APPS
COVERAGE_MODULE_EXCLUDES = [
    'tests$', 'settings$', 'urls$', 'locale$',
    'migrations', 'fixtures', 'admin$', 'django_extensions',
]
COVERAGE_MODULE_EXCLUDES += EXTERNAL_APPS

if not settings.configured:
    settings.configure(
        DATABASES={
            "default": {
                "ENGINE": "django.db.backends.sqlite3",
                "NAME": ":memory:",
            }
        },
        INSTALLED_APPS=INSTALLED_APPS,
        COVERAGE_MODULE_EXCLUDES=COVERAGE_MODULE_EXCLUDES,
        COVERAGE_REPORT_HTML_OUTPUT_DIR=os.path.join(
            os.path.dirname(__file__), 'coverage')
    )


from django_coverage.coverage_runner import CoverageRunner
from django_nose import NoseTestSuiteRunner


class NoseCoverageTestRunner(CoverageRunner, NoseTestSuiteRunner):
    """Custom test runner that uses nose and coverage"""
    pass


def runtests(*test_args):
    failures = NoseCoverageTestRunner(verbosity=2, interactive=True).run_tests(test_args)
    sys.exit(failures)


if __name__ == '__main__':
    runtests(*sys.argv[1:])




from django.db import models
from django.utils.translation import ugettext_lazy as _


class AbstractMaterial(models.Model):
    name = models.CharField(_("Name"), max_length=20, unique=True)

    class Meta:
        abstract = True
        verbose_name = _("Material")
        verbose_name_plural = _("Material")
        ordering = ['name']

    def __unicode__(self):
        return self.name


class AbstractMaterialPercentage(models.Model):
    """Intermediate model"""
    material = models.ForeignKey('Material', related_name='material_percentages')
    percentage = models.PositiveIntegerField(_("Percentage"), help_text=_("Between 0 and 100"))

    class Meta:
        abstract = True
        unique_together = (("material", "percentage"),)
        ordering = ['-percentage']

    def __unicode__(self):
        return "%s%% %s" % (self.percentage, self.material.name)


class AbstractMaterialComposition(models.Model):
    material_percentages = models.ManyToManyField('MaterialPercentage', verbose_name=_("Material percentages"))

    class Meta:
        abstract = True
        verbose_name = _("Material composition")
        verbose_name_plural = _("Material compositions")

    def __unicode__(self):
        percentages = []
        for mp in self.material_percentages.all():
            percentages.append("%d%% %s" % (mp.percentage, mp.material.name))
        return ", ".join(percentages)


class AbstractProductMaterial(models.Model):
    """Links a material composition to a product, may also be used as an intermediate model."""
    material_composition = models.ForeignKey('MaterialComposition')
    product = models.ForeignKey('Product', related_name='materials')

    class Meta:
        abstract = True
        verbose_name = _("Product material")
        verbose_name_plural = _("Product materials")

    def __unicode__(self):
        return unicode(self.material_composition)




from django.db import models
from django.utils.translation import ugettext_lazy as _


class PackageMeasurementMixin(models.Model):
    length = models.FloatField(_("Length"), default=0)
    width = models.FloatField(_("Width"), default=0)
    height = models.FloatField(_("Height"), default=0)
    weight = models.FloatField(_("Weigth"), default=0)

    class Meta:
        abstract = True




from django.test import TestCase

from eca_catalogue.text.tests.factories import WashingInstructionFactory


class WashingInstructionTest(TestCase):
    def test_model(self):
        obj = WashingInstructionFactory()
        self.assertTrue(obj.pk)

    def test_render_icon(self):
        obj = WashingInstructionFactory()
        self.assertEqual(obj.render_icon(), '<img src="icon.png" alt="text" title="text">')
        obj.icon = None
        self.assertIsNone(obj.render_icon(), None)




from django.contrib import admin


class AbstractMaterialAdmin(admin.ModelAdmin):
    search_fields = ['name',]


class AbstractMaterialPercentageAdmin(admin.ModelAdmin):
    list_display = ['material', 'percentage',]
    search_fields = ['material__name', 'percentage',]
    list_filter = ['material',]


class AbstractMaterialCompositionAdmin(admin.ModelAdmin):
    filter_horizontal = ['material_percentages',]
    list_filter = ['material_percentages__material',]


class AbstractProductMaterialAdmin(admin.ModelAdmin):
    list_display = ['material_composition', 'product',]
    raw_id_fields = ['product',]




from django.contrib import admin
from django.db import models
from django.forms.widgets import TextInput


class AbstractSellingPointAdmin(admin.ModelAdmin):
    """name your foreign key to product model "product" in order to fully utilize this class"""
    search_fields = ['text', 'product__name', 'product__item_number',]
    list_display = ['product', 'text',]
    raw_id_fields = ['product',]
    formfield_overrides = {
        models.CharField: {'widget': TextInput(attrs={'size': '150'})},
    }


class AbstractWashingInstructionAdmin(admin.ModelAdmin):
    list_display = ['text', 'render_icon',]
    search_fields = ['text',]


class AbstractProductWashingInstructionAdmin(admin.ModelAdmin):
    list_display = ['product', 'washing_instruction',]
    raw_id_fields = ['product',]




from django.utils.translation import ugettext_lazy as _


# fieldset for PackageMeasurementMixin, use like: fieldsets.append(package_measurement_fieldset)
package_measurement_fieldset = [_("Package measurement"), {
    'fields': ['length', 'width', 'height', 'weight']
}]




import os
from setuptools import setup, find_packages

import eca_catalogue


def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

setup(
    name='django-eca-catalogue',
    version=eca_catalogue.__version__,
    description='A reusable django app providing a generic product catalog for eComerce projects',
    long_description=read('README.md'),
    license=read('LICENSE'),
    author='byteweaver',
    author_email='contact@byteweaver.net',
    url='https://github.com/byteweaver/django-eca-catalogue',
    packages=find_packages(),
    install_requires=[
        'django',
        'django-treebeard',
    ],
    tests_require=[
        'django-nose',
        'coverage',
        'django-coverage',
        'PIL',
    ],
    test_suite='eca_catalogue.tests',
)



from django.db import models
from django.utils.translation import ugettext_lazy as _


class AbstractSellingPoint(models.Model):
    text = models.CharField(_("Text"), max_length=255)
    product = models.ForeignKey('Product', related_name='selling_points')

    class Meta:
        abstract = True
        verbose_name = _("Selling point")
        verbose_name_plural = _("Selling points")

    def __unicode__(self):
        return self.text


class AbstractWashingInstruction(models.Model):
    icon = models.ImageField(verbose_name=_("Icon"), upload_to='laundry_symbols/', blank=True)
    text = models.CharField(_("Text"), max_length=255)

    class Meta:
        abstract = True
        verbose_name = _("Washing instruction")
        verbose_name_plural = _("Washing instructions")

    def __unicode__(self):
        return self.text

    def render_icon(self):
        if self.icon:
            return '<img src="%s" alt="%s" title="%s">' % (self.icon.url, self.text, self.text)
        else:
            return None
    render_icon.allow_tags = True
    render_icon.short_description = _("Icon")


class AbstractProductWashingInstruction(models.Model):
    washing_instruction = models.ForeignKey('WashingInstruction')
    product = models.ForeignKey('Product', related_name='washing_instructions')

    class Meta:
        abstract = True
        verbose_name = _("Product washing instruction")
        verbose_name_plural = _("Product washing instructions")

    def __unicode__(self):
        return unicode(self.washing_instruction)




from django.db import models
from django.utils.translation import ugettext_lazy as _

from treebeard.mp_tree import MP_Node


class AbstractProductCategory(models.Model):
    name = models.CharField(_("Name"), max_length=128, unique=True)
    description = models.TextField(_("Description"), blank=True, null=True)

    class Meta:
        abstract = True
        verbose_name = _("Product category")
        verbose_name_plural = _("Product categories")
        ordering = ['name']

    def __unicode__(self):
        return self.name


class AbstractNestedProductCategory(MP_Node):
    name = models.CharField(_("Name"), max_length=128)
    description = models.TextField(_("Description"), blank=True, null=True)

    class Meta:
        abstract = True
        verbose_name = _("Product category")
        verbose_name_plural = _("Product categories")
        ordering = []

    def __unicode__(self):
        if not self.is_root():
            return unicode(self.get_parent()) + " -> " + self.name
        return self.name

